# Release Notes
This document contains high level documented changes to the pyhpesse package.

## Version 1.0.0 (23/01/2025) 
1. Initial Release

## Version 1.0.1 (03/02/2025) 
1. Updated generator to include additional python objects in some functions 
2. Formatting (P8P Standards) 

## Version 1.0.2 (05/02/2025) 
1. Updated adminapi class name to AdminApi (P8P Standards) 
2. Renamed class HPESSEAPILogin to HPESecureServiceEdgeApiLogin (P8P Standards) 

## Version 1.0.3 (11/03/2025) 
1. Added in function to create token object from file.
2. Added copywrite licence details to py module files.
